@@ -261,6 +261,21 @@ class AliasInfo:
     valid_regions: list[str]
 
 
+class RunnerState(Enum):
+    RUNNING = "running"
+    PENDING = "pending"
+    UNKNOWN = "unknown"
+
+    @staticmethod
+    def from_proto(proto: isolate_proto.RunnerInfo.State) -> RunnerState:
+        if proto is isolate_proto.RunnerInfo.State.RUNNING:
+            return RunnerState.RUNNING
+        elif proto is isolate_proto.RunnerInfo.State.PENDING:
+            return RunnerState.PENDING
+        else:
+            return RunnerState.UNKNOWN
+
+
 @dataclass
 class RunnerInfo:
     runner_id: str
@@ -270,6 +285,15 @@ class RunnerInfo:
     external_metadata: dict[str, Any]
     revision: str
     alias: str
+    state: RunnerState
+
+
+@dataclass
+class ServiceURLs:
+    playground: str
+    run: str
+    queue: str
+    ws: str
 
 
 @dataclass
@@ -279,12 +303,14 @@ class HostedRunResult(Generic[ResultT]):
     logs: list[Log] = field(default_factory=list)
     result: ResultT | None = None
     stream: Any = None
+    service_urls: ServiceURLs | None = None
 
 
 @dataclass
 class RegisterApplicationResult:
     result: RegisterApplicationResultType | None
     logs: list[Log] = field(default_factory=list)
+    service_urls: ServiceURLs | None = None
 
 
 @dataclass
@@ -421,6 +447,7 @@ def _from_grpc_runner_info(message: isolate_proto.RunnerInfo) -> RunnerInfo:
         external_metadata=external_metadata,
         revision=message.revision,
         alias=message.alias,
+        state=RunnerState.from_proto(message.state),
     )
 
 
@@ -435,6 +462,9 @@ def _from_grpc_register_application_result(
             if not message.HasField("result")
             else RegisterApplicationResultType(message.result.application_id)
         ),
+        service_urls=from_grpc(message.service_urls)
+        if message.HasField("service_urls")
+        else None,
     )
 
 
@@ -445,6 +475,13 @@ def _from_grpc_hosted_run_status(
     return HostedRunStatus(HostedRunState(message.state))
 
 
+@from_grpc.register(isolate_proto.ServiceURLs)
+def _from_grpc_service_urls(
+    message: isolate_proto.ServiceURLs,
+) -> ServiceURLs:
+    return ServiceURLs(message.playground, message.run, message.queue, message.ws)
+
+
 @from_grpc.register(isolate_proto.HostedRunResult)
 def _from_grpc_hosted_run_result(
     message: isolate_proto.HostedRunResult,
@@ -459,6 +496,9 @@ def _from_grpc_hosted_run_result(
         from_grpc(message.status),
         logs=[from_grpc(log) for log in message.logs],
         result=return_value,
+        service_urls=from_grpc(message.service_urls)
+        if message.HasField("service_urls")
+        else None,
     )
 
 
@@ -769,7 +809,7 @@ class FalServerlessConnection:
         return [from_grpc(alias) for alias in response.aliases]
 
     def list_alias_runners(self, alias: str) -> list[RunnerInfo]:
-        request = isolate_proto.ListAliasRunnersRequest(alias=alias)
+        request = isolate_proto.ListAliasRunnersRequest(alias=alias, list_pending=True)
         response = self.stub.ListAliasRunners(request)
         return [from_grpc(runner) for runner in response.runners]
 
@@ -797,6 +837,6 @@ class FalServerlessConnection:
         self.stub.KillRunner(request)
 
     def list_runners(self) -> list[RunnerInfo]:
-        request = isolate_proto.ListRunnersRequest()
+        request = isolate_proto.ListRunnersRequest(list_pending=True)
         response = self.stub.ListRunners(request)
         return [from_grpc(runner) for runner in response.runners]
